==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/ro/base.php <==
<?php

return [
    '<strong>Confirm</strong> post deletion' => '<strong>Confirmă</strong> ștergerea postării',
    '<strong>Move</strong> content' => '<strong>Mută</strong> conținutul',
    '<strong>Permalink</strong> to this post' => '<strong>Link</strong> către acestă postare',
    'Add a member to notify' => 'Adaugă un membru pentru notificare',
    'Archived' => 'Arhivat',
    'Back to stream' => 'Înapoi la activitate',
    'Cancel' => 'Anulează',
    'Cancel Edit' => 'Anulează Editarea',
    'Change to "Private"' => 'Fă privat',
    'Change to "Public"' => 'Fă public',
    'Confirm' => 'Confirmă',
    'Content' => 'Conținut',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Content Tag with invalid contentcontainer_id assigned.',
    'Content has been moved to {spacename}' => 'Conținutul a fost mutat în {spacename}',
    'Could not find requested content!' => 'Nu s-a putut găsi conținutul cerut!',
    'Created by me' => 'Creat de mine',
    'Creation time' => 'Data creării',
    'Delete' => 'Șterge',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Sigur dorești să ștergi această postare? Toate aprecierile și comentariile vor fi pierdute!',
    'Edit' => 'Editează',
    'Filter' => 'Filtrează',
    'I\'m involved' => 'Unde sunt implicat',
    'Invalid content id given!' => 'Invalid content id given!',
    'Invalid request method!' => 'Invalid request method!',
    'Invalid space selection.' => 'Selectarea de spațiu neconformă!',
    'Last update' => 'Ultima actualizare',
    'Load more' => 'Încarcă mai mult',
    'Move content' => 'Mută conținutul',
    'Move to archive' => 'Mută în arhivă',
    'No matches with your selected filters!' => 'Nici o porivire cu filtrele selectate de tine!',
    'None' => 'Nimic',
    'Nothing here yet!' => 'Nimic aici momentan!',
    'Notify members' => 'Notifică membri',
    'Permalink' => 'Link',
    'Pin to top' => 'Anunță',
    'Pinned' => 'Anunț',
    'Public' => 'Public',
    'Submit' => 'Trimite',
    'Tag' => 'Etichetă',
    'Target Space' => 'Spațiul Țintă',
    'The author of this content is not allowed to create private content within the selected space.' => 'Autorul acestui conținut nu îi este permis să creeze conținut privat în spațiul selectat.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Autorul acestui conținut nu îi este permis să creeze conținut public în spațiul selectat.',
    'The content can\'t be moved to its current space.' => 'Conținutul nu poate fi mutat în spațiul curent.',
    'The content has been archived.' => 'Conținutul a fost arhivat.',
    'The content has been deleted.' => 'Conținutul a fost șters.',
    'The content has been unarchived.' => 'Conținutul a fost dezarhivat.',
    'The given name is already in use.' => 'Numele dat este deja în uz.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Modulul {moduleName} nu a fost activat pe spațiul țintă selectat.',
    'This action is disabled!' => 'Această acțiune este dezactivată!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Acest tip de conținut nu poate fi mutat datorită unei setări de modul.',
    'This content type can\'t be moved.' => 'Acest tip de conținut nu poate fi mutat.',
    'This space is archived.' => 'Acest spațiu este arhivat.',
    'This space is not visible!' => 'Acest spațiu nu e vizibil!',
    'Topics' => 'Subiecte',
    'Turn off notifications' => 'Oprește notificările',
    'Turn on notifications' => 'Pornește notificările',
    'Unarchive' => 'Dezarhivează',
    'Unpin' => 'Anulează Anunț',
    'Updated' => 'Actualizat',
    'With attachments' => 'Cu atașamente',
    'You do not have the permission to move this content to the given space.' => 'Nu ai permisiunea să muți conținutul acestui spațiu.',
    'You do not have the permission to move this content.' => 'Nu ai permisiunea să muți acest conținut.',
    'Your last edit state has been saved!' => 'Ultima stare de editare a ta a fost salvată!',
    'in' => 'în',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Activated' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Configure' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Deleted' => '',
    'Draft' => '',
    'Enable' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Private' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/ro/base.php <==
<?php

return [
    '<strong>Move</strong> content' => '<strong>Mută</strong> conținutul',
    '<strong>Permalink</strong> to this post' => '<strong>Link</strong> către acestă postare',
    'Add a member to notify' => 'Adaugă un membru pentru notificare',
    'Archived' => 'Arhivat',
    'Back to stream' => 'Înapoi la activitate',
    'Cancel' => 'Anulează',
    'Cancel Edit' => 'Anulează Editarea',
    'Change to "Private"' => 'Fă privat',
    'Change to "Public"' => 'Fă public',
    'Confirm' => 'Confirmă',
    'Content' => 'Conținut',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Content Tag with invalid contentcontainer_id assigned.',
    'Content has been moved to {spacename}' => 'Conținutul a fost mutat în {spacename}',
    'Could not find requested content!' => 'Nu s-a putut găsi conținutul cerut!',
    'Created by me' => 'Creat de mine',
    'Creation time' => 'Data creării',
    'Delete' => 'Șterge',
    'Edit' => 'Editează',
    'Filter' => 'Filtrează',
    'I\'m involved' => 'Unde sunt implicat',
    'Invalid content id given!' => 'Invalid content id given!',
    'Invalid request method!' => 'Invalid request method!',
    'Invalid space selection.' => 'Selectarea de spațiu neconformă!',
    'Last update' => 'Ultima actualizare',
    'Load more' => 'Încarcă mai mult',
    'Move content' => 'Mută conținutul',
    'Move to archive' => 'Mută în arhivă',
    'No matches with your selected filters!' => 'Nici o porivire cu filtrele selectate de tine!',
    'None' => 'Nimic',
    'Nothing here yet!' => 'Nimic aici momentan!',
    'Notify members' => 'Notifică membri',
    'Permalink' => 'Link',
    'Pin to top' => 'Anunță',
    'Pinned' => 'Anunț',
    'Public' => 'Public',
    'Submit' => 'Trimite',
    'Tag' => 'Etichetă',
    'Target Space' => 'Spațiul Țintă',
    'The author of this content is not allowed to create private content within the selected space.' => 'Autorul acestui conținut nu îi este permis să creeze conținut privat în spațiul selectat.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Autorul acestui conținut nu îi este permis să creeze conținut public în spațiul selectat.',
    'The content can\'t be moved to its current space.' => 'Conținutul nu poate fi mutat în spațiul curent.',
    'The content has been archived.' => 'Conținutul a fost arhivat.',
    'The content has been deleted.' => 'Conținutul a fost șters.',
    'The content has been unarchived.' => 'Conținutul a fost dezarhivat.',
    'The given name is already in use.' => 'Numele dat este deja în uz.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Modulul {moduleName} nu a fost activat pe spațiul țintă selectat.',
    'This action is disabled!' => 'Această acțiune este dezactivată!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Acest tip de conținut nu poate fi mutat datorită unei setări de modul.',
    'This content type can\'t be moved.' => 'Acest tip de conținut nu poate fi mutat.',
    'This space is archived.' => 'Acest spațiu este arhivat.',
    'This space is not visible!' => 'Acest spațiu nu e vizibil!',
    'Topics' => 'Subiecte',
    'Turn off notifications' => 'Oprește notificările',
    'Turn on notifications' => 'Pornește notificările',
    'Unarchive' => 'Dezarhivează',
    'Unpin' => 'Anulează Anunț',
    'Updated' => 'Actualizat',
    'With attachments' => 'Cu atașamente',
    'You do not have the permission to move this content to the given space.' => 'Nu ai permisiunea să muți conținutul acestui spațiu.',
    'You do not have the permission to move this content.' => 'Nu ai permisiunea să muți acest conținut.',
    'Your last edit state has been saved!' => 'Ultima stare de editare a ta a fost salvată!',
    'in' => 'în',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Activated' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Configure' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Deleted' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Enable' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Private' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
